@@ -209,6 +209,16 @@ scv_file_new_from_file(char *fname, GError **error)
 	return scv_file;
 }
 
+void
+scv_file_assign_tab_key(KBButton *kbb)
+{
+	memcpy(kbb->magic, char_type_magic[CHAR_TYPE_TAB], sizeof(kbb->magic));
+	kbb->key_length = 4;
+	g_free(kbb->key);
+	kbb->key = g_strdup(TAB_KEY_STRING);
+	kbb->zero = 0;
+}
+
 gboolean
 scv_file_save(ScvFile *scv_file, GError **error)
 {
