@@ -5,6 +5,8 @@
 
 G_BEGIN_DECLS
 
+#define TAB_KEY_STRING "↹"
+
 typedef struct {
 	unsigned char magic[2];
 	unsigned char key_length;
@@ -53,6 +55,7 @@ ScvFile *scv_file_new_from_file(char *fname, GError **error);
 char *scv_file_read_description(char *fname, GError **error);
 gboolean scv_file_save(ScvFile *scv_file, GError **error);
 ScvFile *scv_file_free(ScvFile *scv_file);
+void scv_file_assign_tab_key(KBButton *kbb);
 
 G_END_DECLS
 
