@@ -185,6 +185,11 @@ choice_sel_changed(GtkTreeSelection *sel, ChoiceParams *cp)
 	set_suggestion_model(GTK_TREE_VIEW(cp->suggestions), cp);
 	g_object_set(G_OBJECT(cp->choice_details), "visible", (KBB_CHAR_TYPE_FROM_MAGIC(cp->kbb) != CHAR_TYPE_TAB), NULL);
 	find_suggestion(cp);
+
+	if (KBB_CHAR_TYPE_FROM_MAGIC(cp->kbb) == CHAR_TYPE_TAB) {
+		scv_file_assign_tab_key(cp->kbb);
+		g_object_set(G_OBJECT(cp->picker), "label", cp->kbb->key, NULL);
+	}
 }
 
 static GtkWidget *
